@@ -1,3 +1,4 @@
+import asyncio
 import requests
 from typing import List
 from PIL import Image
@@ -18,7 +19,7 @@ from .structures import (
     RustItem,
 )
 from .remote.rustplus_proto import *
-from .remote import HeartBeat
+from .remote import HeartBeat, RateLimiter
 from ..commands import CommandOptions
 from ..exceptions import *
 from ..utils import (
@@ -45,6 +46,8 @@ class RustSocket(BaseRustSocket):
         ratelimit_refill: int = 3,
         use_proxy: bool = False,
         use_test_server: bool = False,
+        event_loop: asyncio.AbstractEventLoop = None,
+        rate_limiter: RateLimiter = None,
     ) -> None:
         super().__init__(
             ip=ip,
@@ -58,6 +61,8 @@ class RustSocket(BaseRustSocket):
             heartbeat=HeartBeat(self),
             use_proxy=use_proxy,
             use_test_server=use_test_server,
+            event_loop=event_loop,
+            rate_limiter=rate_limiter,
         )
 
     async def get_time(self) -> RustTime:
@@ -163,7 +168,7 @@ class RustSocket(BaseRustSocket):
         add_vending_machines: bool = False,
         override_images: dict = None,
         add_grid: bool = False,
-    ) -> Image:
+    ) -> Image.Image:
 
         if override_images is None:
             override_images = {}
