@@ -2,10 +2,11 @@ from .exceptions import (
     RateLimitError,
     ServerNotResponsiveError,
     CommandsNotEnabledError,
-    ResponseNotRecievedError,
+    ResponseNotReceivedError,
     PrefixNotDefinedError,
     ImageError,
     ClientNotConnectedError,
     RequestError,
     SmartDeviceRegistrationError,
+    ServerSwitchDisallowedError,
 )
